@@ -17,7 +17,7 @@ from .mixin import ensurable, multilist, paginatedlist, waitable
 from .utils import (ParseError, ensure_one, nodestr, parse_colored_line,
                     popup_error, shelvestr)
 from .widgets import attrwrap, dialog, mainwidget
-
+from .exceptions import CriticalError
 
 class _multiwalker(
         ensurable, waitable, multilist, urwid.SimpleFocusListWalker):
@@ -325,7 +325,7 @@ class changesetwalker(
                 or (getattr(widget, 'rev', None) == rev))
 
     async def _wait(self):
-        async with popup_error(OSError, donotraise=True):
+        async with popup_error((OSError, CriticalError), donotraise=True):
             await super()._wait()
 
 
